@@ -20,7 +20,7 @@ class EKSStack(Stack):
         # nodegroup = container.addEKS_EC2ClusterNodeGroup(self, cluster) 
 
         # FARGATE EKS
-        fargate = container.createEKS_FargateCluster(self, eks_cluster_name, eks_role, vpc)
+        self.fargate = container.createEKS_FargateCluster(self, eks_cluster_name, eks_role, vpc)
 
 
 class EMR_EKSStack(Stack): 
